@@ -1,7 +1,7 @@
 Min.Max.Multivar.PCA <- function(gamma, Sigma_SS, Sigma_T0T0, Sigma_T1T1){ 
 
-  Max.PCA <- t(gamma) %*% Sigma_SS %*% gamma / ( (sqrt(Sigma_T0T0) - sqrt(Sigma_T1T1)   )**2) 
-  Min.PCA <- t(gamma) %*% Sigma_SS %*% gamma / ( (sqrt(Sigma_T0T0) + sqrt(Sigma_T1T1)   )**2) 
+  Max.PCA <- min(t(gamma) %*% Sigma_SS %*% gamma / ( (sqrt(Sigma_T0T0) - sqrt(Sigma_T1T1)   )**2), 1) 
+  Min.PCA <- max(t(gamma) %*% Sigma_SS %*% gamma / ( (sqrt(Sigma_T0T0) + sqrt(Sigma_T1T1)   )**2), 0)
   
   cat("\n \nMin PCA: ", Min.PCA)
   cat("\n \nMax PCA: ", Max.PCA, "\n \n")  
@@ -11,4 +11,4 @@ fit <-
   
   class(fit) <- "Min.Max.Multivar.PCA"
   fit
-}
\ No newline at end of file
+}
